@@ -149,10 +149,11 @@ class APTPlugin(Plugin):
                     continue
                 default.append(name)
         sudo().cc(["apt-get", "install", "-y"] + default)
+        sudo().cc(["apt-mark", "auto"] + default)
         for package in manual:
             p = Path(package["path"]).expanduser()
-            check_call(["build.sh"], pwd=p)
-            sudo().cc(["apt", "install", "-y", f'{package["name"]}.deb'], pwd=p)
+            check_call([p / "build.sh"], pwd=p)
+            sudo().cc(["apt", "install", "-y", f'./{package["name"]}.deb'], pwd=p)
 
     def uninstall(self, names):
         sudo().cc(["apt-mark", "auto"] + names)
@@ -165,17 +166,24 @@ class SnapPlugin(Plugin):
 
     def installed(self):
         try:
-            return check_output(["snap", "list"])
+            out = set()
+            for line in check_output(["snap", "list"]).decode("utf-8").splitlines()[1:]:
+                if line in ("core",):
+                    continue
+                out.add(line)
+            return out
         except:
             logging.warning("Failed to get snap packages", exc_info=True)
             return []
 
     def install(self, names):
-        for name in names:
+        for package in names:
             options = []
-            if isinstance(name, dict):
-                name = name["name"]
-                options = name["options"]
+            if isinstance(package, dict):
+                name = package["name"]
+                options = package["options"]
+            else:
+                name = package
             sudo().cc(["snap", "install", name] + options)
 
     def uninstall(self, names):
