@@ -8,7 +8,12 @@ for line in sys.stdin:
         continue
     pargs, kwargs = json.loads(line)
     ret = subprocess.run(
-        *pargs, stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True, **kwargs
+        *pargs,
+        stdin=None,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+        text=True,
+        **kwargs
     )
     sys.stdout.write(
         json.dumps(dict(code=ret.returncode, out=ret.stdout, err=ret.stderr,)) + "\n"
